#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012, 2013. All Rights Reserved.

#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in 

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "No ejecute el script app_upgrade directamente. Para actualizar una aplicacin, ejecute uno de estos mandatos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilice -help para obtener una descripcin completa de los mandatos anteriores."
;;

INVALID_START_DIR )
echo ""
echo "Salvo cuando se utiliza el parmetro -help, el script $2 no se puede ejecutar desde ningn directorio que no sea $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "El archivo '$2' contiene los valores de parmetro del script de actualizacin."
echo "Si necesita modificar alguno de los valores de parmetro predeterminados, puede editar estos archivos o puede especificar los valores de parmetro como argumentos de lnea de mandatos en los scripts de actualizacin."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "El siguiente conjunto de archivos contiene valores de parmetro predeterminados para una actualizacin de aplicacin. Si necesita modificar alguno de los valores de parmetro predeterminados, puede editar estos archivos o puede especificar los valores de parmetro como argumentos de lnea de mandatos en los scripts de actualizacin."
echo "- Actualizacin de DM:   $2/params/dm_params$3.sh"
echo "- Actualizacin de VVC:  $2/params/vvc_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "No se ha especificado ningn tipo de aplicacin. Para actualizar la aplicacin, ejecute uno de estos mandatos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilice -help para obtener una descripcin completa de los mandatos anteriores."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 no es un tipo de aplicacin vlido. Para actualizar la aplicacin, ejecute uno de estos mandatos:"
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "Utilice -help para obtener una descripcin completa de los mandatos anteriores."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Falta un valor para el parmetro $2."
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "El directorio $3 especificado para el parmetro $2 no existe o no es vlido."
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "El directorio $3 especificado para el parmetro $2 debe ser una va de acceso absoluta. "
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "El archivo $3 especificado para el parmetro $2 no existe o no es vlido."
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 es un valor no vlido para el parmetro $2."
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 es un parmetro desconocido."
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Falta el parmetro $2 del directorio de inicio."
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "El directorio $2 no existe o no es vlido."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el mandato repotools de aplicacin '$2'."
echo ""
echo "Compruebe que el parmetro -oldApplicationHome '$3' apunta al directorio de configuracin de servidor antiguo; por ejemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parmetro -oldApplicationHome '$3' apunta al directorio de configuracin de servidor antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el archivo de configuracin '$2'."
echo ""
echo "Compruebe que el parmetro -oldApplicationHome '$3' apunta al directorio de configuracin de servidor antiguo; por ejemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el archivo de configuracin '$2'."
echo ""
echo "Compruebe que el parmetro -oldApplicationHome '$3' apunta al directorio de configuracin de servidor antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parmetro -newApplicationHome '$3' apunta al nuevo directorio de configuracin del servidor de aplicaciones, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo "Si va a realizar una actualizacin desde un release anterior, asegrese de que ha seleccionado las races de contexto correctas.  Por ejemplo, si utiliza Gestor de instalacin, debe seleccionar la opcin de raz de contexto $5 en el panel "Opciones de raz de contexto". Si ha seleccionado por accidente una opcin diferente, debe volver a instalar el producto con la opcin de raz de contexto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el archivo de configuracin '$2'."
echo ""
echo "Compruebe que el parmetro -newApplicationHome '$3' apunta al nuevo directorio de configuracin del servidor JTS, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo "Si va a realizar una actualizacin desde un release anterior, asegrese de que ha seleccionado las races de contexto correctas.  Por ejemplo, si utiliza Gestor de instalacin, debe seleccionar la opcin de raz de contexto $5 en el panel "Opciones de raz de contexto". Si ha seleccionado por accidente una opcin diferente, debe volver a instalar el producto con la opcin de raz de contexto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parmetro -oldJTSHome '$3' apunta al directorio de configuracin del servidor JTS antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el archivo de configuracin '$2'."
echo ""
echo "Compruebe que el parmetro -oldJTSHome '$3' apunta al directorio de configuracin del servidor JTS antiguo, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parmetro -newJTSHome '$3' apunta al nuevo directorio de configuracin del servidor JTS, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el archivo de configuracin '$2'."
echo ""
echo "Compruebe que el parmetro -newJTSHome '$3' apunta al nuevo directorio de configuracin del servidor JTS, por ejemplo, 'JazzInstallDir/server/conf' y que el parmetro jtsContextRoot '$4' es correcto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Falta el archivo tar que contiene los datos de la versin 2.x necesarios para actualizar $2."
echo "Utilice -help para obtener una descripcin completa de los parmetros."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_dm )
echo ""
echo ""
echo "============================================="
echo "===    Actualizacin de DM    ==="
echo "============================================="
echo ""
;;

BANNER_vvc )
echo ""
echo ""
echo "============================================"
echo "===    Actualizacin de VVC    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "La ltima ejecucin fall en el paso inicial..."
;;

LAST_STEP_FAILED )
echo ""
echo "La ltima ejecucin fall en el paso $2..."
echo "Desea reiniciar la actualizacin desde este paso o desde otro anterior?"
;;

ALREADY_RUN )
echo ""
echo "La actualizacin se ha realizado y ha finalizado satisfactoriamente..."
echo "Desea iniciar una nueva a partir de un determinado paso?"
;;

LAST_STEP_PASSED )
echo ""
echo "La ltima ejecucin se detuvo satisfactoriamente en el paso $2..."
echo "Desea reiniciar la actualizacin desde el paso $3 actual o desde otro anterior?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Especifique el nmero de paso [$2-$3] desde el que desee reiniciar la actualizacin o pulse la tecla [Intro] para cancelar:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' no es un nmero. Especifique un nmero de paso vlido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' no es un nmero de paso vlido. Especifique un nmero de paso vlido."
;;

MAX_STEP_NUMBER )
echo ""
echo "El ltimo paso es $2; por lo tanto, no podr reiniciar la actualizacin en el paso $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "El paso $2 no se ha ejecutado todava; por lo tanto, no podr reiniciar la actualizacin en el paso $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Paso 0: descartar tablas"
echo "-------------------"
;;

STEP_0 )
echo "Paso 0: Actualizar archivos de configuracin"
echo "---------------------------"
;;

STEP_1_ADD )
echo "Paso 1: Aadir tablas"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Paso $2: Volver a crear ndices de texto"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "Paso $2: Volver a crear ndices de consulta y de bsqueda"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Paso 2: Actualizar el esquema de depsito de datos"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "La actualizacin $2 fall en el paso $3.  Corrija el problema y vuelva a ejecutar el script comenzando por el paso $3."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_DM )
echo ""
echo "La actualizacin de $2 ha sido satisfactoria. Si tambin a actualizado JTS, puede iniciar ahora los servidores en el despliegue."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_VVC )
echo ""
echo "La actualizacin de $2 ha sido satisfactoria. Si tambin ha actualizado JTS y cualquier aplicacin dependiente (como DM), ahora puede iniciar los servidores en el despliegue."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Directorio: $2"
echo "Mandato:"
;;

ENTER_STEP_ACTION )
echo "Especifique [E] para ejecutar este paso, [S] para omitirlo o pulse [Intro] para cancelar la ejecucin del script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' no es una entrada vlida; solo se permiten 'E', 'S' o 'Intro'"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Se abrir un editor vi para permitirle verificar el archivo teamserver.properties de $2."
echo "Verifique que la raz del URI pblico indicada por la propiedad com.ibm.team.repository.server.webapp.url es correcta."
echo "Verifique que las propiedades de la base de datos son correctas."
echo "Cuando haya finalizado, guarde los cambios, si hay alguno, y cierre el editor para continuar ejecutando el script."
echo ""
;;

PAUSE )
echo ""
echo "Escriba [C] para proseguir la ejecucin o pulse [Intro] para cancelar la ejecucin del script:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' no es una entrada vlida; solo se permiten 'C' o 'Intro'"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "No se han podido copiar los ndices de '$2' a '$3'."
echo "Compruebe la propiedad com.ibm.team.fulltext.indexLocation"
echo "definida en el archivo teamserver.properties."
echo "Copie manualmente los ndices de texto en este directorio"
echo "o ejecute repotools -rebuildTextIndices para volver a crearlos."
echo ""
;;

COPY_TRS_DB_FAILED )
echo ""
echo "No se ha podido copiar la base de datos TRS de '$2' a '$3'."
echo "Compruebe la propiedad com.ibm.xtools.trs.database"
echo "definida en el archivo teamserver.properties."
echo "Copie manualmente la jerarqua del directorio de bases de datos TRS."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "No hay ningn URI pblico definido en"
echo "$3,"
echo "por lo que no se puede iniciar la actualizacin."
echo ""
echo "Debe haber un URI pblico en este archivo definido de la forma siguiente:"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad del URI pblico com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Aada la propiedad al archivo teamserver.properties de la instalacin anterior y establezca el valor para que sea la raz de URI que utilicen todos los clientes para localizar el servidor."
echo "La raz de URI pblico es esencial para un funcionamiento correcto de la nueva instalacin. La actualizacin no se realizar correctamente sin esta propiedad. "
echo "Para obtener ms informacin, consulte el tema del InfoCenter sobre 'Planificacin de sus URI'."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Todos los URI pblicos definidos en"
echo "$3,"
echo "se han comentado, por lo tanto, no se puede iniciar la actualizacin."
echo ""
echo "Debe haber un URI pblico sin comentar en este archivo definido del siguiente modo:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad del URI pblico com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Aada la propiedad al archivo teamserver.properties de la instalacin anterior y establezca el valor para que sea la raz de URI que utilicen todos los clientes para localizar el servidor."
echo "La raz de URI pblico es esencial para un funcionamiento correcto de la nueva instalacin. La actualizacin no se realizar correctamente sin esta propiedad."
echo "Para obtener ms informacin, consulte el tema del InfoCenter sobre 'Planificacin de sus URI'."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "La raz de contexto para JTS se ha establecido en '$2'."
echo "La raz de contexto para la aplicacin se ha establecido en '$3'."
echo "La raz de contexto para jts y la aplicacin no puede ser la misma."
echo ""
;;

esac

}
