#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Umgebungsvariablen gem den Parametern und Standard-
# # werten im Script dm_upgrade.sh definieren
# #
# #===========================================================
# #
# # Diese Datei wird zu Beginn der Ausfhrung des Scripts
# # gelesen. Pro gltigem Parameter wird eine
# # Umgebungsvariable mit vordefiniertem Standardwert gesetzt.
# #
# # Benutzer knnen den Standardwert modifizieren und das
# # Script dm_upgrade.sh mit eigenen Werten starten. Die
# # Parameter und ihre Werte mssen dann nicht manuell in
# # der Befehlszeile eingegeben werden.
# #
# # WARNUNG:
# # Nicht alle Variablen mssen fr jede Anwendung gesetzt
# # werden.  Modifizieren Sie einen Wert erst, nachdem Sie
# # sorgfltig den zugehrigen Kommentar gelesen haben.
# #
# #############################################################

# Parameter: -oldApplicationHome
# Syntax: -oldApplicationHome <verzeichnispfad>
# Beschreibung:
#  Vollstndiger Pfad zum Ausgangsverzeichnis fr Anwendungen
#  in der alten Installation
# Standardwert:
# 	<keiner>
# Einschrnkungen:
#  - Dies ist ein obligatorischer Parameter.
#  - <verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conff' endet.
#    Beispiel:    /opt/ibm/JazzInstallDir/server/conf
#
OLD_APPLICATION_HOME=

# Parameter: -applicationContextRoot
# Syntax: -applicationContextRoot <root>
# Beschreibung:
# Kontextstammverzeichnis der Anwendung.
# Standardwert:
#  	dm
# Einschrnkungen:
#  - <root> muss ein gltiger Verzeichnisname
#    ohne vorangestellten Schrgstrich sein.
#
APPLICATION_CONTEXT_ROOT=dm

# Parameter: -oldApplicationVersion
# Syntax: -oldApplicationVersion <version>
# Beschreibung:
# 	Die DM-Version, die aktualisiert wird.  Standardmig wird
#  dies durch die Ausfhrung von repotools -version in der alten Anwendung ermittelt.
# Standardwert:
# 	<keiner>
# Beschrnkungen:
#  - Muss eine vollstndige Versionszeichenfolge sein.
#    Beispiel: 4.0
#
OLD_APPLICATION_VERSION=

# Parameter: -newApplicationHome
# Syntax: -newApplicationHome <verzeichnispfad>
# Beschreibung:
# 	Pfad zum Ausgangsverzeichnis fr Anwendungen in der neuen Installation
# Standardwert:
# 	<aktuelles_verzeichnis>/conf
# Einschrnkungen:
#  - Dies ist ein obligatorischer Parameter.
#  - <verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conff' endet.
#    Beispiel: /opt/ibm/JazzInstallDir/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parameter: -updateAppServerFiles
# Syntax: -updateAppServerFiles <yes | no>
# Beschreibung:
#  Angabe, ob die Konfigurationsdateien des Standardanwendungsservers (WebSphere Liberty) aktualisiert werden sollen.
# Standardwert:
#   yes
# Einschrnkungen:
#  - Gltig sind nur die Werte 'yes' und 'no'.
#
UPDATE_APPSERVER_FILES=yes

# Parameter: -updateTomcatFiles
# Syntax: -updateTomcatFiles <yes | no>
# Beschreibung:
#   Gibt an, ob die Tomcat-Konfigurationsdateien aktualisiert werden sollen.
# Standardwert:
#   no
# Einschrnkungen:
#  - Gltig sind nur die Werte 'yes' und 'no'.
#
UPDATE_TOMCAT_FILES=no

# Parameter: -oldApplicationTomcatHome
# Syntax: -oldApplicationTomcatHome <verzeichnispfad>
# Beschreibung:
# 	Vollstndiger Pfad zum Tomcat-Stammverzeichnis in der alten Installation
# Standardwert:
# 	<keiner>
# Einschrnkungen:
#  - Muss ein vorhandenes Verzeichnis sein.
#
OLD_APP_TOMCAT_HOME=

# Parameter: -newApplicationTomcatHome
# Usage: -newApplicationTomcatHome <verzeichnispfad>
# Beschreibung:
# 		Pfad zum Tomcat-Stammverzeichnis fr Anwendungen in der neuen Installation.
# Standardwert:
# 	<keiner>
#
NEW_APP_TOMCAT_HOME=

# Parameter: -newJTSHome
# Usage: -newJTSHome <verzeichnispfad>
# Beschreibung:
# 	Pfad zum JTS-Serverkonfigurationsverzeichnis der JTS, die die neue Installation verwendet.
# Standardwert:
#  Ausgangsverzeichnis der neuen Anwendung
# Einschrnkungen:
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit 'server\conf' endet.
#
NEW_JTS_HOME=

# Parameter: -jtsContextRoot
# Syntax: -jtsContextRoot <root>
# Beschreibung:
# 	Kontextstammverzeichnis des JTS-Servers.
# Standardwert:
#  	jts
# Einschrnkungen:
#  - <root> muss ein gltiger Verzeichnisname
#    ohne vorangestellten Schrgstrich sein.
#
JTS_CONTEXT_ROOT=jts

# Parameter: -noPrompt
# Syntax: -noPrompt
# Beschreibung:
#  Beim Erstellen oder Modifizieren der Tabellen keine Besttigung anfordern
# Standardwert:
# 	<ohne>
# Einschrnkungen:
#  - Die einzigen gltigen Werte sind eine leere Zeichenfolge und 'noPrompt'.
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parameter: -noVerify
# Syntax: -noVerify
# Beschreibung:
#  Keine Verifizierung fr Team-Server-Eigenschaftendateien durchfhren
# Standardwert:
# 	<keiner>
# Einschrnkungen:
#  - Die einzigen gltigen Werte sind eine leere Zeichenfolge und 'noVerify'.
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parameter: -overwrite
# Syntax: -overwrite
# Beschreibung:
#  Angabe, ob vorhandene Dateien berschrieben werden sollen
# Standardwert:
#   no
# Einschrnkungen:
#  - Die einzigen gltigen Werte sind eine leere Zeichenfolge und 'overwrite=yes'.
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parameter: -noStepPrompt
# Syntax: -noStepPrompt
# Beschreibung:
# 	Keine Besttigung fr die Ausfhrung eines Schrittes anfordern
# Standardwert:
#   false
# Einschrnkungen:
#  - Die einzigen gltigen Werte sind eine 'true' oder 'false'.
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
