#!/bin/sh
# *******************************************************************************
#  Materiales bajo licencia - Propiedad de IBM
#  (c) Copyright IBM Corporation 2012. Reservados todos los derechos.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Defina las variables de entorno correspondientes a los
# # parámetros dm_upgrade.sh y sus valores predeterminados
# #
# #===========================================================
# #
# # Este archivo se lee al principio de la ejecución del
# # script dm_upgrade.sh. Define una variable de entorno por
# # cada parámetro válido con un valor predeterminado
# # Es posible que los usuarios deseen modificar el valor
# # predeterminado para lanzar el script dm_upgrade.sh con
# # sus propios valores sin tener que especificar de forma
# # manual el parámetro y su valor correspondiente en la
# # línea de mandatos.
# #
# # AVISO:
# # No es necesario definir todas las variables para cada
# # aplicación. Lea cada comentario detenidamente antes de
# # modificar su valor.
# #
# #############################################################

# Parámetro: -oldApplicationHome
# Uso: -oldApplicationHome <vía_directorio>
# Descripción:
#	Vía de acceso completa al directorio de inicio de la
# aplicación en la instalación anterior.
# Predeterminado:
# 	<ninguno>
# Restricciones:
#  - Este parámetro es obligatorio
#  - <vía_directorio> debe ser un directorio existente que
#    termine en 'server/conf'
#    p.e. /opt/ibm/JazzInstallDir/server/conf
#
OLD_APPLICATION_HOME=

# Parámetro: -applicationContextRoot
# Uso: -applicationContextRoot <raíz>
# Descripción:
# 	Raíz de contexto de aplicación.
# Predeterminado:
# 	dm
# Restricciones:
#  - <raíz> debe ser un nombre único de directorio válido
#    (es decir, ninguna barra inclinada inicial)
#
APPLICATION_CONTEXT_ROOT=dm

# Parámetro: -oldApplicationVersion
# Uso: -oldApplicationVersion <versión>
# Descripción:
# 	La versión de DM que se está actualizando. De forma
#  predeterminada se determina ejecutando repotools -version
#  para la aplicación DM antigua.
# Predeterminado:
# 	<ninguno>
# Restricciones:
#  - debería ser una serie con la versión completa como,
#    por ejemplo, 4.0
#
OLD_APPLICATION_VERSION=

# Parámetro: -newApplicationHome
# Uso: -newApplicationHome <vía_directorio>
# Descripción:
# 	Vía de acceso al directorio de inicio de la aplicación en la
#  nueva instalación.
# Predeterminado:
# 	<dir_actual>/conf
# Restricciones:
#  - Este parámetro es obligatorio
#  - <vía_directorio> debe ser un directorio existente que
#    finalice por 'server/conf'
#    p.e. /opt/ibm/JazzInstallDir/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parámetro: -updateAppServerFiles
# Uso: -updateAppServerFiles <yes | no>
# Descripción:
#   Indica si se deben actualizar los archivos de configuración
#   del servidor de aplicaciones predeterminado (WebSphere Liberty).
# Predeterminado:
#   yes
# Restricciones:
#  - Los únicos valores válidos son 'yes' y 'no'
#
UPDATE_APPSERVER_FILES=yes

# Parámetro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descripción:
#   Indica si se deben actualizar los archivos de configuración
#   de tomcat.
# Predeterminado:
#   no
# Restricciones:
#  - Los únicos valores válidos son 'yes' y 'no'
#
UPDATE_TOMCAT_FILES=no

# Parámetro: -oldApplicationTomcatHome
# Uso: -oldApplicationTomcatHome <vía_directorio>
# Descripción:
# 	Vía de acceso completa al directorio raíz de Tomcat en
#  instalación anterior.
# Predeterminado:
# 	<ninguno>
# Restricciones:
#  - Debe ser un directorio existente
#
OLD_APP_TOMCAT_HOME=

# Parámetro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <vía_directorio>
# Descripción:
# 	Vía de acceso al directorio raíz de Application Tomcat
#  en la nueva instalación.
# Predeterminado:
# 	<ninguno>
#
NEW_APP_TOMCAT_HOME=

# Parámetro: -newJTSHome
# Uso: -newJTSHome <vía_directorio>
# Descripción:
# 	Vía de acceso al directorio de configuración del
#  servidor de JTS que la nueva instalación.
# Predeterminado
# 	El nuevo directorio de inicio de la aplicación
# Restricciones:
#  - <vía_directorio> debe ser un directorio existente que
#    termine en 'server/conf'
#
NEW_JTS_HOME=

# Parámetro: -jtsContextRoot
# Uso: -jtsContextRoot <raíz>
# Descripción:
# 	Raíz de contexto del servidor de JTS.
# Predeterminado:
# 	jts
# Restricciones:
#  - <raíz> debe ser un nombre único de directorio válido
#    (es decir, ninguna barra inclinada inicial)
#
JTS_CONTEXT_ROOT=jts

# Parámetro: -noPrompt
# Uso: -noPrompt
# Descripción:
# 	No se muestra ninguna solicitud antes de crear o modificar tablas
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los únicos valores válidos son vacío o 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parámetro: -noVerify
# Uso: -noVerify
# Descripción:
#	No realizar verificación de los archivos teamserver.properties.
# Predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los únicos valores válidos son vacío o 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parámetro: -overwrite
# Uso: -overwrite
# Descripción:
#	Si debe sobrescribirse algún archivo existente.
# Predeterminado:
# 	no
# Restricciones:
#  - Los únicos valores válidos son vacío o 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parámetro: -noStepPrompt
# Uso: -noStepPrompt
# Descripción:
# 	No mostrar solicitud antes de ejecutar un paso.
# Predeterminado:
#   false
# Restricciones:
#  - Los únicos valores válidos son 'true' y 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
