#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Определите переменные среды, соответствующие параметрам
# # сценария dm_upgrade.sh, и их значения по умолчанию
# #
# #===========================================================
# #
# # Этот файл считывается в начале каждого выполнения сценария
# # dm_upgrade.sh. Для каждого допустимого параметра он
# # инициализирует переменную среды предопределенным
# # значением по умолчанию.
# #
# # Пользователям может потребоваться изменить значение по
# # умолчанию, чтобы запускать dm_upgrade.sh со своими
# # значениями, не вводя параметр и его значение вручную
# # в командной строке.
# #
# # ПРЕДУПРЕЖДЕНИЕ:
# # Для некоторых приложений требуется указывать не все
# # переменные.  Внимательно ознакомьтесь с комментарием
# # перед изменением значения.
# #
# #############################################################

# Параметр: -oldApplicationHome
# Формат: -oldApplicationHome <путь-к-каталогу>
# Описание:
# 	Полный путь к домашнему каталогу приложения в старой версии.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - это обязательный параметр
#  - <путь к каталогу> должен задавать существующий каталог и оканчиваться на 'server/conf'
#    Пример: /opt/ibm/JazzInstallDir/server/conf
#
OLD_APPLICATION_HOME=

# Параметр: -applicationContextRoot
# Формат: -applicationContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст приложения.
# Значение по умолчанию:
# 	dm
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога (без начальной косой черты)
#
APPLICATION_CONTEXT_ROOT=dm

# Параметр: -oldApplicationVersion
# Формат: -oldApplicationVersion <версия>
# Описание:
# 	Обновляемая версия DM.  По умолчанию она
# определяется командой repotools -version, выполняемой с прежним приложением.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - необходимо указать полную строку версии
#    например: 4.0
#
OLD_APPLICATION_VERSION=

# Параметр: -newApplicationHome
# Формат: -newApplicationHome <путь-к-каталогу>
# Описание:
# 	Путь к домашнему каталогу приложения в новой версии.
# Значение по умолчанию:
# 	<текущий-каталог>/conf
# Ограничения:
#  - это обязательный параметр
#  - <путь к каталогу> должен задавать существующий каталог и оканчиваться на 'server/conf'
#    например: /opt/ibm/JazzInstallDir/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Параметр: -updateAppServerFiles
# Формат: -updateAppServerFiles <yes | no>
# Описание:
# Управляет обновлением файлов конфигурации сервера приложений по умолчанию (WebSphere Liberty).
# Значение по умолчанию:
# 	yes
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_APPSERVER_FILES=yes

# Параметр: -updateTomcatFiles
# Формат: -updateTomcatFiles <yes | no>
# Описание:
# 	Разрешает/запрещает обновление файлов конфигурации Tomcat.
# Значение по умолчанию:
# 	no
# Ограничения:
#  - Допустимы только значения 'yes' и 'no'
#
UPDATE_TOMCAT_FILES=no

# Параметр: -oldApplicationTomcatHome
# Формат: -oldApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Полный путь к корневому каталогу Tomcat в старом экземпляре.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - каталог должен существовать
#
OLD_APP_TOMCAT_HOME=

# Параметр: -newApplicationTomcatHome
# Формат: -newApplicationTomcatHome <путь-к-каталогу>
# Описание:
# 	Путь к корневому каталогу Tomcat приложения в новой версии.
# Значение по умолчанию:
# 	<нет>
#
NEW_APP_TOMCAT_HOME=

# Параметр: -newJTSHome
# Формат: -newJTSHome <путь-к-каталогу>
# Description:
# 	Путь к каталогу конфигурации сервера JTS в новой версии
# Значение по умолчанию:
# 	Новый домашний каталог приложения
# Ограничения:
#  - <путь-к-каталогу> должен существовать и оканчиваться на 'server/conf'
#
NEW_JTS_HOME=

# Параметр: -jtsContextRoot
# Формат: -jtsContextRoot <корневой-контекст>
# Описание:
# 	Корневой контекст сервера JTS.
# Значение по умолчанию:
# 	jts
# Ограничения:
#  - <корневой-контекст> должен быть коротким именем каталога (без начальной косой черты)
#
JTS_CONTEXT_ROOT=jts

# Параметр: -noPrompt
# Формат: -noPrompt
# Описание:
# 	Не показывать приглашение перед созданием или изменением таблиц
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только пустое значение и значение 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Параметр: -noVerify
# Формат: -noVerify
# Описание:
# 	Не выполнять проверку файлов teamserver.properties.
# Значение по умолчанию:
# 	<нет>
# Ограничения:
#  - Допустимо только значение 'noVerify' и пустое значение
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Параметр: -overwrite
# Формат: -overwrite
# Описание:
# 	Включает режим замены существующих файлов.
# Значение по умолчанию:
# 	no
# Ограничения:
#  - Допустимо только пустое значение и значение 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Параметр: -noStepPrompt
# Формат: -noStepPrompt
# Описание:
# 	Не выводить запрос перед выполнением шага.
# Значение по умолчанию:
#   false
# Ограничения:
#  - Допустимы только значения 'true' и 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
