#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # 定義對應於 dm_upgrade.sh Script 參數
# # 及其預設值的環境變數
# #
# #===========================================================
# #
# # 開始執行 dm_upgrade.sh Script 時，
# # 會讀取這個檔案。這個檔案會為每一個有效的參數，預
# # 先定義一個預設值，來設定一個環境變數。
# #
# # 使用者可能想要修改預設值，
# # 從而以其自己的值來啟動
# # dm_upgrade.sh Script，而無需
# # 手動在指令行中輸入參數及其對應的值。 
# #
# # 警告：
# # 對每一個應用程式來說，並非所有的變數
# # 都需要設定。修改值之前，請仔細閱讀每
# # 一則註解。
# #
# #############################################################

# 參數：-oldApplicationHome
# 用法：-oldApplicationHome <dir path>
# 說明：
# 	舊安裝中應用程式起始目錄的完整路徑。
# 預設值：
# 	<無>
# 限制：
#  - 這是必要參數
#  - <dir path> 必須是現有目錄，且以 'server/conf' 結尾
#    例如：/opt/ibm/JazzInstallDir/server/conf
#
OLD_APPLICATION_HOME=

# 參數：-applicationContextRoot
# 用法：-applicationContextRoot <root>
# 說明：
# 	應用程式環境定義根目錄。
# 預設值：
# 	dm
# 限制：
#  - <root> 必須是有效的目錄單一名稱（即，沒有前導斜線）
#
APPLICATION_CONTEXT_ROOT=dm

# 參數：-oldApplicationVersion
# 用法：-oldApplicationVersion <version>
# 說明：
# 	正在升級的 DM 的版本。依預設，這是透過對舊應用程式
#      執行 repotools -version 來判斷。
# 預設值：
# 	<無>
# 限制：
#  - 應該為完整的版本字串
#    例如 4.0
#
OLD_APPLICATION_VERSION=

# 參數：-newApplicationHome
# 用法：-newApplicationHome <dir path>
# 說明：
# 	新安裝中應用程式起始目錄的路徑。
# 預設值：
# 	<currentDir>/conf
# 限制：
#  - 這是必要參數
#  - <dir path> 必須是現有目錄，且以 'server/conf' 結尾
#    例如：/opt/ibm/JazzInstallDir/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# 參數：-updateAppServerFiles
# 用法：-updateAppServerFiles <yes | no>
# 說明：
#   是否更新預設應用程式伺服器 (WebSphere Liberty) 配置檔。
# 預設值：
#   yes
# 限制：
#  - 唯一有效值是 'yes' 和 'no'
#
UPDATE_APPSERVER_FILES=yes

# 參數：-updateTomcatFiles
# 用法：-updateTomcatFiles <yes | no>
# 說明：
#   是否更新 Tomcat 配置檔。
# 預設值：
#   no
# 限制：
#  - 唯一有效值是 'yes' 和 'no'
#
UPDATE_TOMCAT_FILES=no

# 參數：-oldApplicationTomcatHome
# 用法：-oldApplicationTomcatHome <dir path>
# 說明：
# 	舊安裝中 Tomcat 根目錄的完整路徑。
# 預設值：
# 	<無>
# 限制：
#  - 必須是現有目錄
#
OLD_APP_TOMCAT_HOME=

# 參數：-newApplicationTomcatHome
# 用法：-newApplicationTomcatHome <dir path>
# 說明：
# 	新安裝中應用程式 Tomcat 根目錄的路徑。
# 預設值：
# 	<無>
#
NEW_APP_TOMCAT_HOME=

# 參數：-newJTSHome
# 用法：-newJTSHome <dir path>
# 說明：
# 	新安裝將使用的 JTS 之 JTS 伺服器配置目錄的路徑
# 預設值：
# 	新的應用程式起始目錄
# 限制：
#  - <dir path> 必須是現有目錄，且結尾是 'server/conf'
#
NEW_JTS_HOME=

# 參數：-jtsContextRoot
# 用法：-jtsContextRoot <root>
# 說明：
# 	JTS 伺服器的環境定義根目錄。
# 預設值：
# 	jts
# 限制：
#  - <root> 必須是有效的目錄單一名稱（即，沒有前導斜線）
#
JTS_CONTEXT_ROOT=jts

# 參數：-noPrompt
# 用法：-noPrompt
# 說明：
# 	在開始建立或修改表格之前不先提示
# 預設值：
# 	<無>
# 限制：
#  - 唯一有效值是空的或 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# 參數：-noVerify
# 用法：-noVerify
# 說明：
# 	不執行 teamserver.properties 檔驗證。
# 預設值：
# 	<無>
# 限制：
#  - 唯一有效值是空的或 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# 參數：-overwrite
# 用法：-overwrite
# 說明：
# 	是否改寫任何現有的檔案。
# 預設值：
# 	no
# 限制：
#  - 唯一有效值是空的或 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# 參數：-noStepPrompt
# 用法：-noStepPrompt
# 說明：
# 	在開始執行步驟之前不先提示。
# 預設值：
# 	false
# 限制：
#  - 唯一有效值是 'true' 或 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
